#!/usr/bin/env python
# coding: utf-8
# Copyright (c) 2018
# Gmail:liuzheng712
#

__version__ = '0.0.11'

from .ali import ali
from .aws import aws
from .jms import jms
from .es import ESStore


def init(config):
    if config['TYPE'] == 's3':
        return aws(config)
    elif config['TYPE'] == 'oss':
        return ali(config)
    else:
        return None



#!/usr/bin/env python
# coding: utf-8
# Copyright (c) 2018
# Gmail:liuzheng712
#

import sys
import os
import unittest

sys.path.append('..')
import jms_storage
import config


class TestStorageFunc(unittest.TestCase):
    file_tmp_path = '/tmp/README.md'
    file_locale_path = os.path.abspath(os.path.join(os.getcwd(), os.path.pardir, 'README.md'))
    file_remote_path = 'README.md'

    def test_upload_file(self):
        self.assertTrue(self.client.delete_file(self.file_remote_path))
        self.assertTrue(self.client.upload_file(self.file_locale_path, self.file_remote_path))

    def test_download_file(self):
        if os.path.isfile(self.file_tmp_path):
            os.remove(self.file_tmp_path)
        self.assertTrue(self.client.download_file(self.file_remote_path, self.file_tmp_path))

    def test_generate_presigned_url(self):
        # print(self.client.generate_presigned_url(self.file_remote_path))
        pass


class TestAWS(TestStorageFunc):
    client = jms_storage.aws(config.aws_config)

    def test_type(self):
        self.assertEqual(self.client.type(), 's3')


class TestAli(TestStorageFunc):
    client = jms_storage.ali(config.ali_config)

    def test_type(self):
        self.assertEqual(self.client.type(), 'oss')


def suite():
    suite = unittest.TestSuite()
    test_cases = ['test_type',
                  'test_upload_file',
                  'test_download_file',
                  'test_generate_presigned_url',
                  ]

    for test_class in test_cases:
        suite.addTest(TestAWS(test_class))
        suite.addTest(TestAli(test_class))

    return suite


if __name__ == '__main__':
    runner = unittest.TextTestRunner()
    runner.run(suite())



# -*- coding: utf-8 -*-
#
import oss2


class ali:
    def __init__(self, config):
        self.ENDPOINT = config.get("ENDPOINT", None)
        self.BUCKET = config.get("BUCKET", None)
        self.ACCESS_KEY = config.get("ACCESS_KEY", None)
        self.SECRET_KEY = config.get("SECRET_KEY", None)
        if self.ACCESS_KEY and self.SECRET_KEY:
            self.auth = oss2.Auth(self.ACCESS_KEY, self.SECRET_KEY)
        else:
            self.auth = None
        if self.auth and self.ENDPOINT and self.BUCKET:
            self.client = oss2.Bucket(self.auth, self.ENDPOINT, self.BUCKET)
        else:
            self.client = None

    def type(self):
        return 'oss'

    def upload_file(self, filepath, remote_path):
        try:
            self.client.put_object_from_file(remote_path, filepath)
            return True
        except:
            return False

    def has_file(self, remote_path):
        return self.client.object_exists(remote_path)

    def download_file(self, remote_path, locale_path):
        try:
            self.client.get_object_to_file(remote_path, locale_path)
            return True
        except:
            return False
